@@ -26,6 +26,9 @@ import traceback
 
 import shade
 
+from ansible.module_utils.basic import AnsibleModule
+from ansible.module_utils.openstack import openstack_full_argument_spec
+
 
 class SanityChecks(object):
     # TODO(pbourke): remove and replace with direct call to os_object
@@ -56,8 +59,6 @@ def main():
         module.exit_json(failed=True, changed=True,
                          msg=repr(traceback.format_exc()))
 
-# import module snippets
-from ansible.module_utils.basic import *  # noqa
-from ansible.module_utils.openstack import *  # noqa
+
 if __name__ == '__main__':
     main()
